
typedef struct Page_nums
	{
	int start_page;
	long obj_num;
	int eval;
	char Type;
	};

/*
7.3.1 Page Labels
Each page in a PDF document is identified by an integer page index that expresses
the pages relative position within the document. In addition, a document may
optionally define page labels (PDF 1.3) to identify each page visually on the screen
or in print. Page labels and page indices need not coincide: the indices are fixed,
running consecutively through the document starting from 0 for the first page,
Interactive Features CHAPTER 7 but the labels can be specified in any way that is appropriate for
the particular
document. For example, if the document begins with 12 pages of front matter
numbered in roman numerals and the remainder of the document is numbered
in arabic, then the first page would have a page index of 0 and a page label of i, the
twelfth page would have index 11 and label xii, and the thirteenth page would
have index 12 and label 1.
For purposes of page labeling, a document can be divided into labeling ranges,
each of which is a contiguous set of pages using the same numbering system.
Pages within a range are numbered sequentially in ascending order. A pages label
consists of a numeric portion based on its position within its labeling range,
optionally preceded by a label prefix denoting the range itself. For example, the
pages in an appendix might be labeled with decimal numeric portions prefixed
with the string A-; the resulting page labels would be A-1, A-2, and so on.
A documents labeling ranges are defined by the PageLabels entry in the document
catalog (see Section 3.6.1, Document Catalog). The value of this entry is a
number tree (Section 3.8.5, Number Trees), each of whose keys is the page
index of the first page in a labeling range; the corresponding value is a page label
dictionary defining the labeling characteristics for the pages in that range. The
tree must include a value for page index 0. Table 7.5 shows the contents of a page
label dictionary. (See implementation note 50 in Appendix H.) Example 7.3
shows a document with pages labeled
i, ii, iii, iv, 1, 2, 3, A-8, A-9, 
Example 7.3
1 0 obj
<< /Type /Catalog
/PageLabels << /Nums [ 0 << /S /r >> % A number tree containing
4 << /S /D >> % three page label dictionaries
7 << /S /D /P (A-) /St 8 >>
]
>>

>>
endobj

Page-Level Navigation 7.3

TABLE 7.5 Entries in a page label dictionary
KEY						TYPE							VALUE
*/



#define PAGE_LABEL_DICT_TYPE		1
#define PAGE_LABEL_DICT_S				2
#define PAGE_LABEL_DICT_P				3
#define PAGE_LABEL_DICT_St			4

#define NUMBERING_STYLE_D				1
#define NUMBERING_STYLE_R				2
#define NUMBERING_STYLE_r				3
#define NUMBERING_STYLE_A				4
#define NUMBERING_STYLE_a				5


typedef struct page_label_dict
	{
	int	Type;															/* (Optional) The type of PDF object that this dictionary describes; if present, must be
																					PageLabel for a page label dictionary.	*/
	int S;																/* (Optional) The numbering style to be used for the numeric portion of each page label:
																							D		Decimal arabic numerals
																							R		Uppercase roman numerals
																							r		Lowercase roman numerals
																							A		Uppercase letters (A to Z for the first 26 pages, AA to ZZ for the next 26, and so on)
																							a		Lowercase letters (a to z for the first 26 pages, aa to zz for the next 26, and so on)
								There is no default numbering style; if no S entry is present, page labels will consist solely
								of a label prefix with no numeric portion. For example, if the P entry (below) specifies the
								label prefix Contents, each page will simply be labeled Contents with no page number. (If
								the P entry is also missing or empty, the page label will be an empty string.)				*/
	char	P[16];													/*		text string				(Optional) The label prefix for page labels in this range.	*/
	int	St;																/*	integer		(Optional) The value of the numeric portion for the first page label in the range. Subsequent
																						pages will be numbered sequentially from this value, which must be greater than
																						or equal to 1. Default value: 1.		*/
	};






#define PAGE_LABEL_KIDS			1
#define PAGE_LABEL_NUMS			2
#define PAGE_LABEL_LIMITS		3

/*
3.8.5 Number Trees
A number tree is similar to a name tree (see Section 3.8.4, Name Trees), except
that its keys are integers instead of strings, sorted in ascending numerical order.
The entries in the leaf (or root) nodes containing the key-value pairs are named
Nums instead of Names as in a name tree. Table 3.24 shows the entries in a number
trees node dictionaries.
Functions 3.9
*/

typedef struct page_labels
	{
	long	Kids;										/*	(Root and intermediate nodes only; required in intermediate nodes; present in the root node
																		if and only if Nums is not present) An array of indirect references to the immediate children
																		of this node. The children may be intermediate or leaf nodes.			*/
	int nums_acc;									/* How many Nums and nums are there in the memory											*/
	struct page_label_dict *nums;
	struct Page_nums	*Nums;			/*	(Root and leaf nodes only; required in leaf nodes; present in the root node if and only if Kids
																		is not present) An array of the form [key1 value1 key2 value2  keyn valuen]
																		where each keyi is an integer and the corresponding valuei is an indirect reference to the
																		object associated with that key. The keys are sorted in numerical order, analogously to
																		the arrangement of keys in a name tree as described in Section 3.8.4, Name Trees.		*/
	long	Limits;									/*	(Intermediate and leaf nodes only; required) An array of two integers, specifying the (numerically)
																		least and greatest keys included in the Nums array of a leaf node or in the
																		Nums arrays of any leaf nodes that are descendants of an intermediate node.	*/
	};